@@ -3,7 +3,7 @@ check_validator <- function(x, copy = TRUE, check_infeasible = TRUE){
   if (!inherits(x, "validator")){
     stop("This method needs a 'validator' object, but was given a '", class(x), "'.",call. = FALSE)
   }
-  if (isTRUE(check_infeasible) && is_infeasible(x)){
+  if (isTRUE(check_infeasible) && is_infeasible(x, verbose=FALSE)){
     stop("This rule set is infeasible. Please fix and repair the rule set with `make_feasible` before continuing.", call. = FALSE)
   }
   invisible(x)
@@ -26,11 +26,11 @@ get_variables_num <- function(x){
 }
 
 get_variables_cat <- function(x){
-  var_cat <- sapply(to_miprules(x), function(mr){
+  var_cat <- lapply(to_miprules(x), function(mr){
     nms <- names(mr$type)
     nms[mr$type == "binary" & grepl(":", nms)]
   })
-  var_cat <- unique(unlist(var_cat))
+  var_cat <- unique(var_cat |> unlist())
   if (length(var_cat) == 0){
     return(
       data.frame( bin_variable = character(0)
